@@ -87,7 +87,7 @@ class WebSocket(object):
         uwsgi_args = ' '.join(['--{0} {1}'.format(k,v) for k,v in kwargs.items()])
         args = 'uwsgi --http {0}:{1} --http-websockets {2} --wsgi {3}'.format(host, port, uwsgi_args, app)
 
-        print args
+        print(args)
 
         # set enviromental variable to trigger adding debug middleware
         if self.app.debug or debug:
